@@ -142,7 +142,7 @@ for s in ipairs(states) do
 		paramtype = "light",
 		paramtype2 = "facedir",
 		groups = dgroups,
-		sounds = default.node_sound_wood_defaults(),
+		sounds = default.node_sound_metal_defaults(),
 		walkable = true,
 		pipe_connections = { top = 1 },
 		after_place_node = function(pos)
@@ -194,7 +194,7 @@ for s in ipairs(states) do
 			fixed = { -5/16, -4/16, -8/16, 5/16, 5/16, 8/16 }
 		},
 		groups = dgroups,
-		sounds = default.node_sound_wood_defaults(),
+		sounds = default.node_sound_metal_defaults(),
 		walkable = true,
 		on_place = pipeworks.rotate_on_place,
 		after_dig_node = function(pos)
@@ -240,7 +240,7 @@ minetest.register_node(nodename_valve_loaded, {
 		fixed = { -5/16, -4/16, -8/16, 5/16, 5/16, 8/16 }
 	},
 	groups = {snappy=3, pipe=1, not_in_creative_inventory=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -289,7 +289,7 @@ minetest.register_node("pipeworks:grating", {
 	sunlight_propagates = true,
 	paramtype = "light",
 	groups = {snappy=3, pipe=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	pipe_connections = { top = 1 },
 	after_place_node = function(pos)
@@ -313,7 +313,7 @@ minetest.register_node(nodename_spigot_empty, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	pipe_connections = { left=1, right=1, front=1, back=1,
 						 left_param2 = 3, right_param2 = 1, front_param2 = 2, back_param2 = 0 },
@@ -355,7 +355,7 @@ minetest.register_node(nodename_spigot_loaded, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1, not_in_creative_inventory=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	pipe_connections = { left=1, right=1, front=1, back=1,
 						 left_param2 = 3, right_param2 = 1, front_param2 = 2, back_param2 = 0 },
@@ -409,7 +409,7 @@ minetest.register_node(nodename_panel_empty, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -429,7 +429,7 @@ minetest.register_node(nodename_panel_loaded, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1, not_in_creative_inventory=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -456,7 +456,7 @@ minetest.register_node(nodename_sensor_empty, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -495,7 +495,7 @@ minetest.register_node(nodename_sensor_loaded, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1, not_in_creative_inventory=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -560,7 +560,7 @@ for fill = 0, 10 do
 		paramtype = "light",
 		paramtype2 = "facedir",
 		groups = {snappy=3, pipe=1, tankfill=fill+1, not_in_creative_inventory=1},
-		sounds = default.node_sound_wood_defaults(),
+		sounds = default.node_sound_metal_defaults(),
 		walkable = true,
 		drop = "pipeworks:storage_tank_0",
 		pipe_connections = { top = 1, bottom = 1},
@@ -588,7 +588,7 @@ for fill = 0, 10 do
 		paramtype = "light",
 		paramtype2 = "facedir",
 		groups = sgroups,
-		sounds = default.node_sound_wood_defaults(),
+		sounds = default.node_sound_metal_defaults(),
 		walkable = true,
 		drop = "pipeworks:storage_tank_0",
 		pipe_connections = { top = 1, bottom = 1},
@@ -614,7 +614,7 @@ minetest.register_node(nodename_fountain_empty, {
 	sunlight_propagates = true,
 	paramtype = "light",
 	groups = {snappy=3, pipe=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	pipe_connections = { bottom = 1 },
 	after_place_node = function(pos)
@@ -648,7 +648,7 @@ minetest.register_node(nodename_fountain_loaded, {
 	sunlight_propagates = true,
 	paramtype = "light",
 	groups = {snappy=3, pipe=1, not_in_creative_inventory=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	pipe_connections = { bottom = 1 },
 	after_place_node = function(pos)
@@ -698,7 +698,7 @@ minetest.register_node(nodename_sp_empty, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -706,7 +706,9 @@ minetest.register_node(nodename_sp_empty, {
 	end,
 	selection_box = sp_cbox,
 	collision_box = sp_cbox,
-	on_rotate = pipeworks.fix_after_rotation
+	on_rotate = pipeworks.fix_after_rotation,
+	check_for_pole = pipeworks.check_for_vert_pipe,
+	check_for_horiz_pole = pipeworks.check_for_horiz_pipe
 })
 
 local nodename_sp_loaded = "pipeworks:straight_pipe_loaded"
@@ -718,7 +720,7 @@ minetest.register_node(nodename_sp_loaded, {
 	paramtype = "light",
 	paramtype2 = "facedir",
 	groups = {snappy=3, pipe=1, not_in_creative_inventory=1},
-	sounds = default.node_sound_wood_defaults(),
+	sounds = default.node_sound_metal_defaults(),
 	walkable = true,
 	on_place = pipeworks.rotate_on_place,
 	after_dig_node = function(pos)
@@ -727,7 +729,9 @@ minetest.register_node(nodename_sp_loaded, {
 	selection_box = sp_cbox,
 	collision_box = sp_cbox,
 	drop = "pipeworks:straight_pipe_empty",
-	on_rotate = pipeworks.fix_after_rotation
+	on_rotate = pipeworks.fix_after_rotation,
+	check_for_pole = pipeworks.check_for_vert_pipe,
+	check_for_horiz_pole = pipeworks.check_for_horiz_pipe
 })
 
 new_flow_logic_register.directional_horizonal_rotate(nodename_sp_empty, true)
