@@ -193,6 +193,8 @@ local function punch_filter(data, filtpos, filtnode, msg)
 		["technic:mv_grinder"] = "dst",
 		["technic:mv_grinder_active"] = "dst",
 		["technic:tool_workshop"] = "src",
+		["technic:mv_freezer"] = "dst",
+		["technic:mv_freezer_active"] = "dst"
 	}
 
 	-- make sure there's something appropriate to inject the item into
@@ -383,6 +385,7 @@ for _, data in ipairs({
 			pipeworks.after_place(pos)
 		end,
 		after_dig_node = pipeworks.after_dig,
+		on_rotate = pipeworks.on_rotate,
 		allow_metadata_inventory_put = function(pos, listname, index, stack, player)
 			if not pipeworks.may_configure(pos, player) then
 				return 0
@@ -472,18 +475,18 @@ end
 minetest.register_craft( {
 	output = "pipeworks:filter 2",
 	recipe = {
-	        { "default:steel_ingot", "default:steel_ingot", "homedecor:plastic_sheeting" },
-	        { "group:stick", "default:mese_crystal", "homedecor:plastic_sheeting" },
-	        { "default:steel_ingot", "default:steel_ingot", "homedecor:plastic_sheeting" }
+	        { "default:steel_ingot", "default:steel_ingot", "basic_materials:plastic_sheet" },
+	        { "group:stick", "default:mese_crystal", "basic_materials:plastic_sheet" },
+	        { "default:steel_ingot", "default:steel_ingot", "basic_materials:plastic_sheet" }
 	},
 })
 
 minetest.register_craft( {
 	output = "pipeworks:mese_filter 2",
 	recipe = {
-	        { "default:steel_ingot", "default:steel_ingot", "homedecor:plastic_sheeting" },
-	        { "group:stick", "default:mese", "homedecor:plastic_sheeting" },
-	        { "default:steel_ingot", "default:steel_ingot", "homedecor:plastic_sheeting" }
+	        { "default:steel_ingot", "default:steel_ingot", "basic_materials:plastic_sheet" },
+	        { "group:stick", "default:mese", "basic_materials:plastic_sheet" },
+	        { "default:steel_ingot", "default:steel_ingot", "basic_materials:plastic_sheet" }
 	},
 })
 
@@ -491,9 +494,9 @@ if minetest.get_modpath("digilines") then
 	minetest.register_craft( {
 		output = "pipeworks:digiline_filter 2",
 		recipe = {
-			{ "default:steel_ingot", "default:steel_ingot", "homedecor:plastic_sheeting" },
-			{ "group:stick", "digilines:wire_std_00000000", "homedecor:plastic_sheeting" },
-			{ "default:steel_ingot", "default:steel_ingot", "homedecor:plastic_sheeting" }
+			{ "default:steel_ingot", "default:steel_ingot", "basic_materials:plastic_sheet" },
+			{ "group:stick", "digilines:wire_std_00000000", "basic_materials:plastic_sheet" },
+			{ "default:steel_ingot", "default:steel_ingot", "basic_materials:plastic_sheet" }
 		},
 	})
 end
